@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-07-16 17:48:27
+@LastEditTime: 2021-08-13 18:10:40
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -12,6 +12,7 @@ from emoji import unicode_codes
 import random
 import datetime
 import re
+import ast
 
 class SevenHelper:
     """
@@ -29,44 +30,43 @@ class SevenHelper:
         if not db:
             db = config.get_value("redis")["db"]
         password = config.get_value("redis")["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses)
+        redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses=decode_responses)
         return redis_cli
 
     @classmethod
-    def is_continue_request(self, redis_key, expire=2):
+    def is_continue_request(self, cache_key, expire=500):
         """
         :description: 请求太频繁校验
-        :param redis_key：自定义redis_key
-        :param expire：过期时间，单位秒
-        :return: bool true-代表跳过限制，false-代表连续请求进行限制
+        :param cache_key：自定义cache_key
+        :param expire：过期时间，单位毫秒
+        :return: bool true-代表连续请求进行限制，false-代表跳过限制
         :last_editors: HuangJianYi
         """
         redis_init = self.redis_init()
-        post_value = redis_init.get(redis_key)
+        post_value = redis_init.get(cache_key)
         if post_value == None:
-            redis_init.set(redis_key, 10, ex=expire)
+            redis_init.set(cache_key, 10, px=expire)
             return False
         return True
 
-
     @classmethod
-    def reids_check_llen(self,queue_name,queue_lenth=100):
-         """
+    def redis_check_llen(self,queue_name,queue_lenth=100):
+        """
          :description: 校验队列长度
          :param queue_name：自定义队列名称
          :param queue_lenth：队列长度
          :return: bool False-代表达到长度限制，进行拦截
          :last_editors: HuangJianYi
          """
-         redis_init = SevenHelper.redis_init()
-         list_len = redis_init.llen(queue_name)
-         if int(list_len) >= int(queue_lenth):
-             return False
-         else:
-             return True
+        redis_init = SevenHelper.redis_init()
+        list_len = redis_init.llen(queue_name)
+        if int(list_len) >= int(queue_lenth):
+            return False
+        else:
+            return True
 
     @classmethod
-    def reids_lpush(self, queue_name, value, expire):
+    def redis_lpush(self, queue_name, value, expire):
         """
          :description: 入队列
          :param queue_name：自定义队列名称
@@ -80,7 +80,7 @@ class SevenHelper:
         redis_init.expire(queue_name,expire)
 
     @classmethod
-    def reids_lpop(self, queue_name):
+    def redis_lpop(self, queue_name):
         """
          :description: 出队列
          :param queue_name：队列名称
@@ -91,7 +91,7 @@ class SevenHelper:
         return result
 
     @classmethod
-    def reids_acquire_lock(self, lock_name, acquire_time=10, time_out=15):
+    def redis_acquire_lock(self, lock_name, acquire_time=10, time_out=15):
         """
         :description: 获取一个分布式锁
         :param lock_name：锁定名称
@@ -115,7 +115,7 @@ class SevenHelper:
         return False,""
 
     @classmethod
-    def reids_release_lock(self, lock_name, identifier):
+    def redis_release_lock(self, lock_name, identifier):
         """
         :description: 释放一个锁
         :param lock_name：锁定名称
@@ -132,19 +132,19 @@ class SevenHelper:
                 lock_value = redis_init.get(lock)
                 if not lock_value:
                     return True
-                if lock_value.decode() == identifier:
+                if lock_value == identifier:
                     pip.multi()
                     pip.delete(lock)
                     pip.execute()
                     return True
                 pip.unwatch()
                 break
-            except redis.excetions.WacthcError:
+            except Exception:
                 pass
         return False
 
     @classmethod
-    def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names):
+    def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names=''):
         """
         :description: 两个字典列表合并
         :param source_dict_list：源字典表
@@ -153,19 +153,26 @@ class SevenHelper:
         :param merge_key：需要合并的字典表用来关联的字段
         :param merge_columns_names：需要合并的字典表中需要展示的字段
         :return: 
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         result = []
+        if merge_columns_names:
+            list_key = list(merge_columns_names.split(","))
+        else:
+            list_key = list(merge_dict_list[0].keys()) if len(merge_dict_list)>0 else []
+
         for source_dict in source_dict_list:
-            info_list = [i for i in merge_dict_list if source_dict[source_key] != "" and i[merge_key] == source_dict[source_key]]
+            info_list = [i for i in merge_dict_list if source_dict[source_key] and str(i[merge_key]) == str(source_dict[source_key])]
             if info_list:
-                list_key = list(merge_columns_names.split(","))
                 source_dict = dict(source_dict, **dict.fromkeys(list_key))
                 for item in list_key:
                     source_dict[item] = info_list[0].get(item)
             else:
-                list1 = list(merge_columns_names.split(","))
-                source_dict = dict(source_dict, **dict.fromkeys(list1))
+                result_key = []
+                for item in list_key:
+                    if item not in source_dict.keys():
+                        result_key.append(item)
+                source_dict = dict(source_dict, **dict.fromkeys(result_key))
             result.append(source_dict)
         return result
 
@@ -320,8 +327,8 @@ class SevenHelper:
         :last_editors: HuangJianYi
         """
         now_date = (datetime.datetime.now() + datetime.timedelta(hours=hours))
-        return int(int(now_date.strftime(fmt)))
-    
+        return int(now_date.strftime(fmt))
+
     @classmethod
     def get_now_hour_int(self, hours=0):
         """
@@ -415,48 +422,6 @@ class SevenHelper:
         order_id = str(cur_time) + str(ran_num)
         return order_id
 
-    @classmethod
-    def lottery_algorithm_chance(self, prize_list):
-        """
-        :description: 抽奖算法（概率）
-        :param prize_list:奖品列表
-        :return: 中奖的奖品
-        :last_editors: HuangJianYi
-        """
-        init_value = 0.00
-        probability_list = []
-        for prize in prize_list:
-            current_prize = prize
-            current_prize["start_probability"] = init_value
-            current_prize["end_probability"] = init_value + float(prize["chance"])
-            probability_list.append(current_prize)
-            init_value = init_value + float(prize["chance"])
-        prize_index = random.uniform(0.00, init_value)
-        for prize in probability_list:
-            if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
-                return prize
-
-    @classmethod
-    def lottery_algorithm(self, prize_list):
-        """
-        :description: 抽奖算法（权重）
-        :param prize_list:奖品列表
-        :return: 中奖的奖品
-        :last_editors: HuangJianYi
-        """
-        init_value = 0
-        probability_list = []
-        for prize in prize_list:
-            current_prize = prize
-            current_prize["start_probability"] = init_value
-            current_prize["end_probability"] = init_value + prize["probability"]
-            probability_list.append(current_prize)
-            init_value = init_value + prize["probability"]
-        prize_index = random.randint(0, init_value - 1)
-        for prize in probability_list:
-            if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
-                return prize
-
     @classmethod
     def emoji_base64_to_emoji(self, text_str):
         """
@@ -491,43 +456,29 @@ class SevenHelper:
 
         return "".join(list_e)
 
-
-      def json_dumps(self, rep_dic):
-        """
-        :description: 将字典转化为字符串
-        :param rep_dic：字典对象
-        :return: str
-        :last_editors: HuangJingCan
-        """
-        if isinstance(rep_dic, str):
-            rep_dic = ast.literal_eval(rep_dic)
-        if hasattr(rep_dic, '__dict__'):
-            rep_dic = rep_dic.__dict__
-        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=2)
-    
     @classmethod
     def json_dumps(self, rep_dic):
         """
         :description: 将字典转化为字符串
         :param rep_dic：字典对象
         :return: str
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         if isinstance(rep_dic, str):
             rep_dic = ast.literal_eval(rep_dic)
         if hasattr(rep_dic, '__dict__'):
             rep_dic = rep_dic.__dict__
-        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=2)
-    
+        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=1)
+
     @classmethod
     def json_loads(self, rep_str):
         """
         :description: 将字符串转化为字典
         :param rep_str：str
         :return: dict
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         try:
             return json.loads(rep_str)
         except Exception as ex:
-            return json.loads(self.json_dumps(rep_str))
\ No newline at end of file
+            return json.loads(self.json_dumps(rep_str))
