@@ -1,4 +1,11 @@
-
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2021-07-15 17:17:08
+@LastEditTime: 2021-08-19 11:35:02
+@LastEditors: HuangJianYi
+@Description: 
+"""
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -13,7 +20,7 @@ class AssetLogModel(BaseModel):
         self.db.context = context
 
     #方法扩展请继承此类
-    
+
 class AssetLog:
 
     def __init__(self):
@@ -37,19 +44,22 @@ class AssetLog:
         self.operate_value = 0  # 操作值
         self.history_value = 0  # 历史值
         self.now_value = 0  # 当前值
+        self.handler_name = ""  # 接口名称
+        self.request_code = ""  # 请求代码
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.create_day = 0  # 创建天
+        self.warn_date = "1900-01-01 00:00:00"  # 预警时间
+        self.warn_day = 0  # 预警天
         self.i1 = 0  # i1
         self.s1 = ""  # s1
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'log_title', 'info_json', 'asset_type', 'asset_object_id', 'source_type', 'source_object_id', 'source_object_name', 'only_id', 'operate_type', 'operate_value', 'history_value', 'now_value', 'create_date', 'create_day', 'i1', 's1']
-        
+        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'log_title', 'info_json', 'asset_type', 'asset_object_id', 'source_type', 'source_object_id', 'source_object_name', 'only_id', 'operate_type', 'operate_value', 'history_value', 'now_value', 'handler_name', 'request_code', 'create_date', 'create_day', 'warn_date', 'warn_day', 'i1', 's1']
+
     @classmethod
     def get_primary_key(self):
         return "id"
 
     def __str__(self):
         return "asset_log_tb"
-    
\ No newline at end of file
