@@ -1,10 +1,18 @@
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2021-07-15 17:17:08
+@LastEditTime: 2021-08-09 09:17:33
+@LastEditors: HuangJianYi
+@Description: 
+"""
 
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
+from seven_cloudapp_frame.models.cache_model import *
 
-
-class AssetOnlyModel(BaseModel):
+class AssetOnlyModel(CacheModel):
     def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
         super(AssetOnlyModel, self).__init__(AssetOnly, sub_table)
         self.db = MySQLHelper(config.get_value(db_connect_key))
